@@ -122,6 +122,14 @@ class SurfingEntrance(object):
         from .data.fund.view.view_data_processor import ViewDataProcessor
         return ViewDataProcessor().process_all(yesterday, yesterday)
 
+    def dev_test(self):
+        import pandas as pd
+        from .data.fund.derived.derived_fund_manager_profit_processor import FundManagerProfitProcess, DerivedDataHelper
+
+        date = '20200930'
+        fsg = FundManagerProfitProcess(DerivedDataHelper())
+        fsg.process(date, date, pd.to_datetime(date).date())
+
     def data_update(self):
         print('Start data update')
 
