@@ -251,6 +251,18 @@ class BasicDataPart1:
         df['tag_method'] = 'PE百分位'
         # index_id是人工起的，所以只能作为参数传进来
         df['index_id'] = index_ids
+        df = df.set_index('index_id')
+        if 'csi_new_ev' in df.index:
+            df.loc['csi_new_ev','desc_name'] = '中证新能源汽车'
+        if 'csi_biomedi' in df.index:
+            df.loc['csi_biomedi','desc_name'] = '中证生物医药'
+        if 'csi_cssw_elec' in df.index:
+            df.loc['csi_cssw_elec','desc_name'] = '中证申万电子'
+        if 'csi_computer' in df.index:
+            df.loc['csi_computer','desc_name'] = '中证计算机'
+        if 'csi_food_beve' in df.index:
+            df.loc['csi_food_beve','desc_name'] = '中证食品饮料'
+        df = df.reset_index()
         self._data_helper._upload_basic(df, IndexInfo.__table__.name)
 
     def index_component(self):
@@ -571,6 +583,12 @@ class BasicDataPart1:
             print(e)
             traceback.print_exc()
             return False
+        '''
+        人工添加 板块对应基金
+        思路1: 东财基金对应概念， 加入有未插入的同概念基金， 如果基金涵盖类别少，手动增加 index_id， 如果类别下基金繁杂，比如材料（涉及钢铁 煤炭 金属 有色 水泥）
+        思路2: 未找到东财基金对应概念，查看板块涉及的指数，找关键字，在基金名称里查找 
+        文件 surfing/rpm/etc/sector_info_extend.txt
+        '''
 
     def fund_size(self, start_date, end_date):
         try:
@@ -601,7 +619,7 @@ class BasicDataPart1:
             # 将场内变为场外的
             df['CODES'] = df.CODES.transform(lambda x: x.split('.')[0] + '.OF' if '.OF' not in x else x)
             # pivot on all remaining columns
-            df = df.drop(columns=['FUNDSCALE', 'UNITTOTAL']).pivot(index='DATES', columns='CODES').fillna(method='ffill')
+            df = df.pivot(index='DATES', columns='CODES').fillna(method='ffill')
             df = df.iloc[[-1], :].stack().reset_index()
             df['fund_id'] = df[['DATES', 'CODES']].apply(lambda x: self._data_helper._get_fund_id_from_order_book_id(x.CODES.split('.')[0], x.DATES), axis=1)
             df = df[df.fund_id.notna()]
@@ -808,9 +826,14 @@ class BasicDataPart1:
             if is_history:
                 # history, update only on report date
                 df = self._raw_data_api.get_em_fund_hold_industry(start_date, end_date)
+                df_qdii = self._raw_data_api.get_em_fund_hold_industry_qdii(start_date, end_date)
+                df = pd.concat([df, df_qdii], axis=0)
             else:
                 real_date = RawDataHelper.get_prev_target_date(end_date, QUARTER_UPDATE_DATE_LIST)
                 df = self._raw_data_api.get_em_fund_hold_industry(real_date, real_date)
+                df_qdii = self._raw_data_api.get_em_fund_hold_industry_qdii(real_date, end_date)
+                df = pd.concat([df, df_qdii], axis=0)
+            
             df['CODES'] = df.apply(lambda x: self._data_helper._get_fund_id_from_order_book_id(x.CODES.split('.')[0], x.DATES), axis=1)
             df = df.dropna(subset=['CODES']).drop(columns='_update_time')
             name_dict = {
@@ -840,9 +863,23 @@ class BasicDataPart1:
             if is_history:
                 # history, update only on report date
                 df = self._raw_data_api.get_em_fund_hold_stock(start_date, end_date)
+                df_qdii = self._raw_data_api.get_em_fund_hold_stock_qdii(start_date, end_date)
+                res_stock = []
+                for r in df_qdii.iterrows():
+                    res_stock.append(self._data_helper._qdii_fund_hold_r(r,'股票'))
+                df_qdii = pd.DataFrame(res_stock)
+                df = pd.concat([df, df_qdii], axis=0)
+
             else:
                 real_date = RawDataHelper.get_prev_target_date(end_date, QUARTER_UPDATE_DATE_LIST)
                 df = self._raw_data_api.get_em_fund_hold_stock(real_date, real_date)
+                df_qdii = self._raw_data_api.get_em_fund_hold_stock_qdii(real_date, end_date)
+                res_stock = []
+                for r in df_qdii.iterrows():
+                    res_stock.append(self._data_helper._qdii_fund_hold_r(r,'股票'))
+                df_qdii = pd.DataFrame(res_stock)
+                df = pd.concat([df, df_qdii], axis=0)
+            
             df['CODES'] = df.apply(lambda x: self._data_helper._get_fund_id_from_order_book_id(x.CODES.split('.')[0], x.DATES), axis=1)
             df = df.dropna(subset=['CODES']).drop(columns='_update_time')
             name_dict = {
@@ -873,9 +910,21 @@ class BasicDataPart1:
             if is_history:
                 # history, update only on report date
                 df = self._raw_data_api.get_em_fund_hold_bond(start_date, end_date)
+                df_qdii = self._raw_data_api.get_em_fund_hold_stock_qdii(start_date, end_date)
+                
             else:
                 real_date = RawDataHelper.get_prev_target_date(end_date, QUARTER_UPDATE_DATE_LIST)
                 df = self._raw_data_api.get_em_fund_hold_bond(real_date, real_date)
+                df_qdii = self._raw_data_api.get_em_fund_hold_stock_qdii(start_date, end_date)
+
+            cols_list = df_qdii.columns.tolist()
+            df_qdii.columns = [i.replace('stock','bond') for i in cols_list]
+            res_bond = []
+            for r in df_qdii.iterrows():
+                res_bond.append(self._data_helper._qdii_fund_hold_r(r,'债券'))
+            df_qdii = pd.DataFrame(res_bond).dropna(axis=0)
+            df = pd.concat([df, df_qdii], axis=0)
+
             df['CODES'] = df.apply(lambda x: self._data_helper._get_fund_id_from_order_book_id(x.CODES.split('.')[0], x.DATES), axis=1)
             df = df.dropna(subset=['CODES']).drop(columns='_update_time')
             name_dict = {
@@ -982,7 +1031,29 @@ class BasicDataPart1:
         stock_fund = stock_fund.reset_index()
         stock_fund['datetime'] = dt
         stock_fund = pd.merge(stock_fund, fund_info[['fund_id','desc_name']].rename(columns={'desc_name':'fund_name'}), on ='fund_id')
-        self._data_helper._upload_basic(stock_fund, FundOpenInfo.__table__.name)
+        # 海外股票简称未处理，过长，仅展示国内股票
+        stock_fund = stock_fund[stock_fund.stock_id.str.contains('.SH') | stock_fund.stock_id.str.contains('.SZ')]
+        self._data_helper._upload_basic(stock_fund, StockInFund.__table__.name)
+
+    def bond_in_fund(self):
+        dt = datetime.date(2020,9,30)
+        bond_info = RawDataApi().get_em_bond_info()
+        fund_info = BasicDataApi().get_fund_info()
+        bond_fund = BasicDataApi().get_fund_hold_bond(dt=dt)
+        bond_fund = bond_fund.set_index('fund_id')
+        cols = [[f'rank{i+1}_bond_code', f'rank{i+1}_bond', f'rank{i+1}_bondweight'] for i in range(10)]
+        res = []
+        for i in cols:
+            df = bond_fund[i]
+            df.columns = ['bond_id','bond_name','bond_weight']
+            res.append(df)
+        bond_fund = pd.concat(res).dropna(axis=0)
+        bond_fund = bond_fund.reset_index()
+        bond_fund['datetime'] = dt
+        bond_fund = pd.merge(bond_fund, fund_info[['fund_id','desc_name']].rename(columns={'desc_name':'fund_name'}), on ='fund_id')
+        # 海外债券简称未处理，过长，仅展示国内债券
+        bond_fund = bond_fund[bond_fund.stock_id.str.contains('.SH') | bond_fund.stock_id.str.contains('.SZ') ｜ bond_fund.stock_id.str.contains('.IB')]
+        self._data_helper._upload_basic(bond_fund, BondInFund.__table__.name)
 
     def process_all(self, start_date, end_date):
         failed_tasks = []
