@@ -15,6 +15,7 @@ from statsmodels.tsa.ar_model import AutoReg
 from pandas.tseries.offsets import DateOffset
 from ...api.raw import RawDataApi
 from ...api.basic import BasicDataApi
+from ...api.derived import DerivedDataApi
 from ...view.derived_models import FundIndicatorGroup
 from .derived_data_helper import DerivedDataHelper, normalize, score_rescale
 
@@ -461,8 +462,49 @@ class FundIndicatorProcessorGroup:
             res.append(_df)
         self.mng_best_fund_now = pd.concat(res)
 
+    def score_rescale(self, df):
+        return df.rank(pct=True) * 100
+
+    def add_mng_score(self):
+        bucket_name = 'tl-fund-dm'
+        _s3_bucket_uri: str = f's3://{bucket_name}/dm'
+        name = 'mng_indicator_score'
+        s3_uri = f'{_s3_bucket_uri}/{name}.parquet'
+        score = pd.read_parquet(s3_uri)
+        
+        mng_info = DerivedDataApi().derived_data(func_name='get_fund_manager_info')
+        mng_dic = mng_info[mng_info.end_date == datetime.date(2040,1,1)]['fund_id']
+
+        # 找基金对应基金经理分数
+        fund_type_list = list(self.fund_indicator_score.fund_type.unique())
+        res = []
+        for fund_type in fund_type_list:
+            _score = score[score.fund_type == fund_type].copy().dropna(subset=['total_score'])
+            _fund_indicator_part = self.fund_indicator_score[self.fund_indicator_score.fund_type == fund_type]#[['total_score']]
+            _score = _score.set_index('mng_id').join(mng_dic)
+            _score = _score.reset_index().set_index('fund_id').rename(columns={'total_score':'mng_score'})[['mng_score']]
+            _score = _score.reset_index().groupby('fund_id').max()
+            _fund_indicator_part = _fund_indicator_part.drop(columns='mng_score').join(_score['mng_score'])
+            res.append(_fund_indicator_part)
+        fund_indicator = pd.concat(res,axis=0)
+        dic = {
+            'stock':['ret_ability','risk_ability','stable_ability','select_time','select_stock','mng_score'],
+            'bond':['ret_ability','risk_ability','stable_ability','select_time','select_stock','mng_score'],
+            'index':['alpha_ability','risk_ability','stable_ability','mng_score'],
+            'QDII':['ret_ability','risk_ability','stable_ability','mng_score'],
+            'mmf':['ret_ability','risk_ability','mng_score']
+        }
+        res = []
+        for fund_type, score_list in dic.items():
+            df = fund_indicator[fund_indicator['fund_type'] == fund_type].copy()
+            df['total_score'] = score_rescale(df[score_list].sum(axis=1))
+            res.append(df)
+        fund_indicator_result = pd.concat(res)
+        self.fund_indicator_score = fund_indicator_result
+
     def to_s3(self):
         bucket_name = 'tl-fund-dm'
         _s3_bucket_uri: str = f's3://{bucket_name}/dm'
         name = 'fund_indicator_score'
-        self.fund_indicator_score.to_parquet(f'{_s3_bucket_uri}/{name}.parquet', compression='gzip')
\ No newline at end of file
+        self.fund_indicator_score.to_parquet(f'{_s3_bucket_uri}/{name}.parquet', compression='gzip')
+        
\ No newline at end of file
