@@ -9,6 +9,7 @@ from ...view.basic_models import FundNav, FundInfo, FundRate, FundSize, FundRet,
     FundStatusLatest
 from ...view.derived_models import FundAlpha, FundIndicator, FundScoreNew, FundManagerInfo
 from ....constant import ExchangeStatus
+from .__init__ import fund_s3_uri
 
 class FundDailyCollectionProcessor(object):
 
@@ -41,6 +42,8 @@ class FundDailyCollectionProcessor(object):
                     FundInfo.benchmark,
                     FundInfo.desc_name,
                     FundInfo.track_index,
+                    FundInfo.manage_fee,
+                    FundInfo.trustee_fee,
                 )
                 funds = pd.read_sql(query.statement, query.session.bind)
                 return funds.set_index('fund_id')
@@ -278,72 +281,6 @@ class FundDailyCollectionProcessor(object):
             except Exception as e:
                 print('Failed fill get data <err_msg> {}'.format(e))
 
-    def get_score_new_df(self):
-        with DerivedDatabaseConnector().managed_session() as mn_session:
-            try:
-                subq = mn_session.query(
-                    FundScoreNew.fund_id.label('temp_id'),
-                    func.max(FundScoreNew.datetime).label('temp_date'),
-                ).filter(FundScoreNew.data_cycle == '1Y').group_by(FundScoreNew.fund_id).subquery()
-
-                query = mn_session.query(
-                    FundScoreNew.fund_id,
-                    FundScoreNew.return_score,
-                    FundScoreNew.robust_score,
-                    FundScoreNew.risk_score,
-                    FundScoreNew.timing_score,
-                    FundScoreNew.selection_score,
-                    FundScoreNew.team_score,
-                    FundScoreNew.total_score,
-                    FundScoreNew.abnormal_reason,
-                ).filter(
-                    FundScoreNew.fund_id == subq.c.temp_id,
-                    FundScoreNew.datetime == subq.c.temp_date,
-                    FundScoreNew.data_cycle == '1Y',
-                )
-
-                df = pd.read_sql(query.statement, query.session.bind)
-                df = df.drop_duplicates(subset=['fund_id'], keep='last')
-                df = df[df['abnormal_reason'].isnull()].drop(columns='abnormal_reason')
-                return df
-
-            except Exception as e:
-                print('Failed get_score_new_df <err_msg> {}'.format(traceback.format_exc()))
-
-    def get_tag_fund_indicator_df(self):
-        with DerivedDatabaseConnector().managed_session() as mn_session:
-            try:
-                latest_time = mn_session.query(FundIndicator).order_by(FundIndicator.datetime.desc()).limit(1).one_or_none()
-                latest_time = latest_time.datetime
-                print(latest_time)
-                query = mn_session.query(
-                    FundIndicator.fund_id,
-                    FundIndicator.alpha,
-                    FundIndicator.beta,
-                    FundIndicator.track_err,
-                    FundIndicator.fee_rate,
-                    FundIndicator.info_ratio,
-                    FundIndicator.treynor,
-                    FundIndicator.mdd,
-                    FundIndicator.down_risk,
-                    FundIndicator.ret_over_period,
-                    FundIndicator.annual_avg_daily_ret,
-                    FundIndicator.annual_vol,
-                    FundIndicator.annual_ret,
-                    FundIndicator.m_square,
-                    FundIndicator.time_ret,
-                    FundIndicator.var,
-                    FundIndicator.r_square,
-                    FundIndicator.sharpe,
-                ).filter(FundIndicator.datetime==latest_time)
-                df = pd.read_sql(query.statement, query.session.bind)
-                df = df.rename(columns={'track_err': 'tag_track_err'})
-                df = df.drop_duplicates(subset=['fund_id'], keep='last')
-                return df
-
-            except Exception as e:
-                print('Failed get_fund_indicator_df <err_msg> {}'.format(e))
-
     def append_data(self, table_name, data_append_directly_data_df):
         if not data_append_directly_data_df.empty:
             with ViewDatabaseConnector().managed_session() as mn_session:
@@ -432,13 +369,44 @@ class FundDailyCollectionProcessor(object):
             # score = self.get_score_df().set_index('fund_id')
             print(score)
             print('-' * 100)
-            new_score = self.get_score_new_df().set_index('fund_id')
+            
+            fund_indicator_score = pd.read_parquet(fund_s3_uri)
+            
+            score_name_dic = {  'ret_ability':'return_score',
+                                'stable_ability':'robust_score',
+                                'risk_ability':'risk_score',
+                                'select_time':'timing_score',
+                                'select_stock':'selection_score',
+                                'mng_score':'team_score',
+                                'total_score':'total_score',
+                            }
+            new_score = fund_indicator_score.rename(columns=score_name_dic)[list(score_name_dic.values())]      
             print(new_score)
             print('-' * 100)
-            tag_indicator = self.get_tag_fund_indicator_df().set_index('fund_id')
+
+            indicator_name_dic = {  'alpha~history_m':'alpha',
+                                    'beta~history_m':'beta',
+                                    'track_err~history_m':'tag_track_err',
+                                    'info_ratio~history_m':'info_ratio',
+                                    'treynor~history_m':'treynor',
+                                    'mdd~history_m':'mdd',
+                                    'downside_std~history_m':'down_risk',
+                                    'total_ret':'ret_over_period',
+                                    'annual_ret~history_m':'annual_avg_daily_ret',
+                                    'annual_vol~history_m':'annual_vol',
+                                    'annual_ret~history_m':'annual_ret',
+                                    'stock_cl_beta~history_w':'time_ret',
+                                    'var~history_m':'var',
+                                    'sharpe~history_m':'sharpe'
+                                }
+            tag_indicator = fund_indicator_score.rename(columns=indicator_name_dic)[list(indicator_name_dic.values())] 
+            tag_indicator = tag_indicator.join(pd.DataFrame(funds.manage_fee + funds.trustee_fee,columns=['fee_rate']))
+            tag_indicator['m_square'] = None
+            tag_indicator['r_square'] = None
             print(tag_indicator)
             print('-' * 100)
-
+            
+            funds = funds.drop(columns=['manage_fee','trustee_fee'])
             exchange_status = self.get_exchange_status_df().set_index('fund_id')
             print(exchange_status)
             print('-' * 100)
