@@ -751,8 +751,7 @@ class FundDataManager(DataManager):
             BarraCNE5FactorProcessor.fund_analysis_plot(fund_ret, factor_ret_contri)
         return params, spec_ret
 
-    def fund_analysis_by_stock_factors(self, fund_id: str, factor_names: Tuple[str], universe: str = 'default') -> Optional[pd.DataFrame]:
-        '''对基金计算因子暴露'''
+    def _get_fund_nav_and_do_preprocessing(self, fund_id: str) -> Optional[pd.Series]:
         try:
             try:
                 fund_nav: pd.Series = self.dts.fund_nav.loc[:, fund_id]
@@ -764,9 +763,30 @@ class FundDataManager(DataManager):
         except KeyError:
             print(f'[fund_analysis_new] do not have nav of {fund_id} as before, can not do analysis')
             return
-        return StockFactorApi.decomp_ret(fund_nav.pct_change(), factor_names, universe)
+        return fund_nav.reindex(fund_nav.index.intersection(self.dts.trading_days.datetime))
 
-    def index_analysis_by_stock_factors(self, index_id: str, factor_names: Tuple[str]) -> Optional[pd.DataFrame]:
+    def fund_return_analysis_by_stock_factors(self, fund_id: str, universe: str = 'default') -> Optional[pd.DataFrame]:
+        '''对基金计算因子收益贡献序列'''
+        fund_nav: Optional[pd.Series] = self._get_fund_nav_and_do_preprocessing(fund_id)
+        if fund_nav is not None:
+            return StockFactorApi.calc_factor_return_contribution(fund_nav.pct_change(), universe)
+
+    def fund_analysis_by_stock_factors(self, fund_id: str, factor_names: Tuple[str], universe: str = 'default') -> Optional[pd.Series]:
+        '''对基金计算因子暴露'''
+        fund_nav: Optional[pd.Series] = self._get_fund_nav_and_do_preprocessing(fund_id)
+        if fund_nav is not None:
+            return StockFactorApi.decomp_ret(fund_nav.pct_change(), factor_names, universe)
+
+    def index_return_analysis_by_stock_factors(self, index_id: str) -> Optional[pd.DataFrame]:
+        '''对指数计算因子收益贡献序列'''
+        try:
+            index_price: pd.Series = self.dts.index_price.loc[:, index_id]
+        except KeyError:
+            print(f'[index_analysis_new] do not have price of {index_id}, can not do analysis')
+            return
+        return StockFactorApi.calc_factor_return_contribution(index_price.pct_change(), 'default')
+
+    def index_analysis_by_stock_factors(self, index_id: str, factor_names: Tuple[str]) -> Optional[pd.Series]:
         '''对指数计算因子暴露'''
         try:
             index_price: pd.Series = self.dts.index_price.loc[:, index_id]
@@ -775,9 +795,9 @@ class FundDataManager(DataManager):
             return
         return StockFactorApi.decomp_ret(index_price.pct_change(), factor_names, 'default')
 
-    def fund_pos_analysis_by_stock_factors(self, fund_id: str, factor_names: Tuple[str], report_date: datetime.date, universe: str = 'default') -> Optional[pd.DataFrame]:
+    def fund_pos_analysis_by_stock_factors(self, fund_id: str, factor_names: Tuple[str], report_date: datetime.date) -> Optional[pd.DataFrame]:
         '''对基金持仓计算因子暴露'''
-        return StockFactorApi.fac_pos(fund_id, factor_names, report_date, universe)
+        return StockFactorApi.fac_pos(fund_id, factor_names, report_date)
 
     def white_and_black_list_filter(self, score, score_raw, disproved_list):
         return self._score_manager._white_and_black_list_filter(score, score_raw, disproved_list)
