@@ -429,44 +429,44 @@ class FundHoldStock(Base):
 
     fund_id = Column(CHAR(10), primary_key=True) # 基金ID
     datetime = Column(DATE, primary_key=True) # 日期
-    rank1_stock = Column(CHAR(20)) #股票名
-    rank1_stock_code = Column(CHAR(16))  # 股票ID
+    rank1_stock = Column(TEXT) #股票名
+    rank1_stock_code = Column(TEXT)  # 股票ID
     rank1_stockval = Column(DOUBLE(asdecimal=False)) #持仓市值
     rank1_stockweight = Column(DOUBLE(asdecimal=False)) #持仓权重
-    rank2_stock = Column(CHAR(20)) #股票名
-    rank2_stock_code = Column(CHAR(16))  # 股票ID
+    rank2_stock = Column(TEXT) #股票名
+    rank2_stock_code = Column(TEXT)  # 股票ID
     rank2_stockval = Column(DOUBLE(asdecimal=False)) #持仓市值
     rank2_stockweight = Column(DOUBLE(asdecimal=False)) #持仓权重
-    rank3_stock = Column(CHAR(20)) #股票名
-    rank3_stock_code = Column(CHAR(16))  # 股票ID
+    rank3_stock = Column(TEXT) #股票名
+    rank3_stock_code = Column(TEXT)  # 股票ID
     rank3_stockval = Column(DOUBLE(asdecimal=False)) #持仓市值
     rank3_stockweight = Column(DOUBLE(asdecimal=False)) #持仓权重
-    rank4_stock = Column(CHAR(20)) #股票名
-    rank4_stock_code = Column(CHAR(16))  # 股票ID
+    rank4_stock = Column(TEXT) #股票名
+    rank4_stock_code = Column(TEXT)  # 股票ID
     rank4_stockval = Column(DOUBLE(asdecimal=False)) #持仓市值
     rank4_stockweight = Column(DOUBLE(asdecimal=False)) #持仓权重
-    rank5_stock = Column(CHAR(20)) #股票名
-    rank5_stock_code = Column(CHAR(16))  # 股票ID
+    rank5_stock = Column(TEXT) #股票名
+    rank5_stock_code = Column(TEXT)  # 股票ID
     rank5_stockval = Column(DOUBLE(asdecimal=False)) #持仓市值
     rank5_stockweight = Column(DOUBLE(asdecimal=False)) #持仓权重
-    rank6_stock = Column(CHAR(20)) #股票名
-    rank6_stock_code = Column(CHAR(16))  # 股票ID
+    rank6_stock = Column(TEXT) #股票名
+    rank6_stock_code = Column(TEXT)  # 股票ID
     rank6_stockval = Column(DOUBLE(asdecimal=False)) #持仓市值
     rank6_stockweight = Column(DOUBLE(asdecimal=False)) #持仓权重
-    rank7_stock = Column(CHAR(20)) #股票名
-    rank7_stock_code = Column(CHAR(16))  # 股票ID
+    rank7_stock = Column(TEXT) #股票名
+    rank7_stock_code = Column(TEXT)  # 股票ID
     rank7_stockval = Column(DOUBLE(asdecimal=False)) #持仓市值
     rank7_stockweight = Column(DOUBLE(asdecimal=False)) #持仓权重
-    rank8_stock = Column(CHAR(20)) #股票名
-    rank8_stock_code = Column(CHAR(16))  # 股票ID
+    rank8_stock = Column(TEXT) #股票名
+    rank8_stock_code = Column(TEXT)  # 股票ID
     rank8_stockval = Column(DOUBLE(asdecimal=False)) #持仓市值
     rank8_stockweight = Column(DOUBLE(asdecimal=False)) #持仓权重
-    rank9_stock = Column(CHAR(20)) #股票名
-    rank9_stock_code = Column(CHAR(16))  # 股票ID
+    rank9_stock = Column(TEXT) #股票名
+    rank9_stock_code = Column(TEXT)  # 股票ID
     rank9_stockval = Column(DOUBLE(asdecimal=False)) #持仓市值
     rank9_stockweight = Column(DOUBLE(asdecimal=False)) #持仓权重
-    rank10_stock = Column(CHAR(20)) #股票名
-    rank10_stock_code = Column(CHAR(16))  # 股票ID
+    rank10_stock = Column(TEXT) #股票名
+    rank10_stock_code = Column(TEXT)  # 股票ID
     rank10_stockval = Column(DOUBLE(asdecimal=False)) #持仓市值
     rank10_stockweight = Column(DOUBLE(asdecimal=False)) #持仓权重
 
@@ -476,44 +476,44 @@ class FundHoldBond(Base):
     __tablename__ = 'fund_hold_bond'
     fund_id = Column(CHAR(20), primary_key=True) # 基金ID
     datetime = Column(DATE, primary_key=True) # 日期
-    rank1_bond = Column(CHAR(30)) #债券名
-    rank1_bond_code =  Column(CHAR(15)) # 债券id
+    rank1_bond = Column(CHAR(60)) #债券名
+    rank1_bond_code =  Column(CHAR(60)) # 债券id
     rank1_bondval = Column(DOUBLE(asdecimal=False)) #持仓市值
     rank1_bondweight = Column(DOUBLE(asdecimal=False)) #持仓权重
-    rank2_bond = Column(CHAR(30)) #债券名
-    rank2_bond_code =  Column(CHAR(15)) # 债券id
+    rank2_bond = Column(CHAR(60)) #债券名
+    rank2_bond_code =  Column(CHAR(60)) # 债券id
     rank2_bondval = Column(DOUBLE(asdecimal=False)) #持仓市值
     rank2_bondweight = Column(DOUBLE(asdecimal=False)) #持仓权重
-    rank3_bond = Column(CHAR(30)) #债券名
-    rank3_bond_code =  Column(CHAR(15)) # 债券id
+    rank3_bond = Column(CHAR(60)) #债券名
+    rank3_bond_code =  Column(CHAR(60)) # 债券id
     rank3_bondval = Column(DOUBLE(asdecimal=False)) #持仓市值
     rank3_bondweight = Column(DOUBLE(asdecimal=False)) #持仓权重
-    rank4_bond = Column(CHAR(30)) #债券名
-    rank4_bond_code =  Column(CHAR(15)) # 债券id
+    rank4_bond = Column(CHAR(60)) #债券名
+    rank4_bond_code =  Column(CHAR(60)) # 债券id
     rank4_bondval = Column(DOUBLE(asdecimal=False)) #持仓市值
     rank4_bondweight = Column(DOUBLE(asdecimal=False)) #持仓权重
-    rank5_bond = Column(CHAR(30)) #债券名
-    rank5_bond_code =  Column(CHAR(15)) # 债券id
+    rank5_bond = Column(CHAR(60)) #债券名
+    rank5_bond_code =  Column(CHAR(60)) # 债券id
     rank5_bondval = Column(DOUBLE(asdecimal=False)) #持仓市值
     rank5_bondweight = Column(DOUBLE(asdecimal=False)) #持仓权重
-    rank6_bond = Column(CHAR(30)) #债券名
-    rank6_bond_code =  Column(CHAR(15)) # 债券id
+    rank6_bond = Column(CHAR(60)) #债券名
+    rank6_bond_code =  Column(CHAR(60)) # 债券id
     rank6_bondval = Column(DOUBLE(asdecimal=False)) #持仓市值
     rank6_bondweight = Column(DOUBLE(asdecimal=False)) #持仓权重
-    rank7_bond = Column(CHAR(30)) #债券名
-    rank7_bond_code =  Column(CHAR(15)) # 债券id
+    rank7_bond = Column(CHAR(60)) #债券名
+    rank7_bond_code =  Column(CHAR(60)) # 债券id
     rank7_bondval = Column(DOUBLE(asdecimal=False)) #持仓市值
     rank7_bondweight = Column(DOUBLE(asdecimal=False)) #持仓权重
-    rank8_bond = Column(CHAR(30)) #债券名
-    rank8_bond_code =  Column(CHAR(15)) # 债券id
+    rank8_bond = Column(CHAR(60)) #债券名
+    rank8_bond_code =  Column(CHAR(60)) # 债券id
     rank8_bondval = Column(DOUBLE(asdecimal=False)) #持仓市值
     rank8_bondweight = Column(DOUBLE(asdecimal=False)) #持仓权重
-    rank9_bond = Column(CHAR(30)) #债券名
-    rank9_bond_code =  Column(CHAR(15)) # 债券id
+    rank9_bond = Column(CHAR(60)) #债券名
+    rank9_bond_code =  Column(CHAR(60)) # 债券id
     rank9_bondval = Column(DOUBLE(asdecimal=False)) #持仓市值
     rank9_bondweight = Column(DOUBLE(asdecimal=False)) #持仓权重
-    rank10_bond = Column(CHAR(30)) #债券名
-    rank10_bond_code =  Column(CHAR(15)) # 债券id
+    rank10_bond = Column(CHAR(60)) #债券名
+    rank10_bond_code =  Column(CHAR(60)) # 债券id
     rank10_bondval = Column(DOUBLE(asdecimal=False)) #持仓市值
     rank10_bondweight = Column(DOUBLE(asdecimal=False)) #持仓权重
 
@@ -667,4 +667,15 @@ class StockInFund(Base):
     stock_weight = Column(DOUBLE(asdecimal=False)) # 股票在基金权重
     fund_name = Column(CHAR(64)) # 基金名称
 
+class BondInFund(Base):
+    '''基金重仓债'''
+
+    __tablename__ = 'bond_in_fund'
+
+    fund_id = Column(CHAR(10), primary_key=True)  # 基金代码
+    bond_id = Column(CHAR(10), primary_key=True) # 债券代码
+    datetime = Column(DATE, primary_key=True) # 日期
+    bond_name = Column(CHAR(64)) # 债券名称
+    bond_weight = Column(DOUBLE(asdecimal=False)) # 债券在基金权重
+    fund_name = Column(CHAR(64)) # 基金名称
     
\ No newline at end of file
