@@ -484,18 +484,25 @@ class EmFundNav(Base):
 
 
 class EmFundScale(Base):
-    '''
-    Choice基金状态表
-    包含基金规模，基金申赎状态
-    '''
+    '''Choice基金规模表'''
 
     __tablename__ = 'em_fund_scale'
 
-    CODES = Column(CHAR(10), primary_key=True)  # 合约代码
+    CODES = Column(CHAR(10), primary_key=True)  # Choice基金ID
     DATES = Column(DATE, primary_key=True)  # 日期
 
-    FUNDSCALE = Column(DOUBLE(asdecimal=False))  # 基金规模
+    QANALNETASSET = Column('FUNDSCALE', DOUBLE(asdecimal=False))  # 基金规模
     UNITTOTAL = Column(DOUBLE(asdecimal=False))  # 基金份额
+
+
+class EmFundStatus(Base):
+    '''Choice基金状态表'''
+
+    __tablename__ = 'em_fund_status'
+
+    CODES = Column(CHAR(10), primary_key=True)  # Choice基金ID
+    DATES = Column(DATE, primary_key=True)  # 日期
+
     PURCHSTATUS = Column(CHAR(16))  # 申购状态
     REDEMSTATUS = Column(CHAR(16))  # 赎回状态
     LPLIMIT = Column(DOUBLE(asdecimal=False))  # 暂停大额申购上限
@@ -609,7 +616,14 @@ class EmStockInfo(Base):
     CSRCCODENEW = Column("csrc_code_new", CHAR(16)) # 所属证监会行业(新)代码
     CSINDCODE2016 = Column("cs_ind_code_2016", CHAR(32)) # 所属中证行业(2016)代码
     GICSCODE = Column("gics_code", CHAR(32), nullable=False) # 所属GICS行业代码
-
+    CAPUNCAPDATE = Column("cap_uncap_date", TEXT) # 戴帽摘帽日期
+    DELISTDATE = Column("delist_date", DATE) # 摘牌日期
+    BCODE = Column("b_code", CHAR(10)) # 同公司B股代码
+    BNAME = Column("b_name", TEXT) # 同公司B股简称
+    HCODE = Column("h_code", CHAR(10)) # 同公司H股代码
+    HNAME = Column("h_name", TEXT) # 同公司H股简称
+    BACKDOOR = Column("backdoor", BOOLEAN, nullable=False) # 是否借壳上市
+    BACKDOORDATE = Column("backdoor_date", DATE) # 借壳上市日期
 
 class EmStockFinFac(Base):
     '''Choice股票财务因子 '''
@@ -1063,6 +1077,20 @@ class EMFundHoldIndustry(Base):
     rank3_indname = Column(CHAR(50)) #第三排名行业名称
     rank3_indweight = Column(DOUBLE(asdecimal=False)) #第三排名行业市值占基金资产总值比
 
+class EMFundHoldIndustryQDII(Base):
+    '''东财基金行业配置'''
+
+    __tablename__ = 'em_fund_industry_qdii'
+
+    CODES = Column(CHAR(20), primary_key=True) # 东财基金ID
+    DATES = Column(DATE, primary_key=True) # 日期
+    rank1_indname = Column(CHAR(50)) #第一排名行业名称
+    rank1_indweight = Column(DOUBLE(asdecimal=False)) #第一排名行业市值占基金资产总值比
+    rank2_indname = Column(CHAR(50)) #第二排名行业名称
+    rank2_indweight = Column(DOUBLE(asdecimal=False)) #第二排名行业市值占基金资产总值比
+    rank3_indname = Column(CHAR(50)) #第三排名行业名称
+    rank3_indweight = Column(DOUBLE(asdecimal=False)) #第三排名行业市值占基金资产总值比
+
 class EMFundHoldStock(Base):
     '''东财基金重仓股'''
 
@@ -1111,6 +1139,114 @@ class EMFundHoldStock(Base):
     rank10_stockval = Column(DOUBLE(asdecimal=False)) #持仓市值
     rank10_stockweight = Column(DOUBLE(asdecimal=False)) #持仓权重
 
+class EMFundHoldStockQDII(Base):
+    '''东财基金QDII重仓信息'''
+
+    __tablename__ = 'em_fund_stock_qdii'
+
+    CODES = Column(CHAR(20), primary_key=True) # 东财基金ID
+    DATES = Column(DATE, primary_key=True) # 日期
+    rank1_stock = Column(TEXT) #股票名
+    rank1_stock_code = Column(TEXT)  # 股票ID
+    rank1_stockval = Column(DOUBLE(asdecimal=False)) #持仓市值
+    rank1_stockweight = Column(DOUBLE(asdecimal=False)) #持仓权重
+    rank1_type = Column(CHAR(20)) #类型
+    rank2_stock = Column(TEXT) #股票名
+    rank2_stock_code = Column(TEXT)  # 股票ID
+    rank2_stockval = Column(DOUBLE(asdecimal=False)) #持仓市值
+    rank2_stockweight = Column(DOUBLE(asdecimal=False)) #持仓权重
+    rank2_type = Column(CHAR(20)) #类型
+    rank3_stock = Column(TEXT) #股票名
+    rank3_stock_code = Column(TEXT)  # 股票ID
+    rank3_stockval = Column(DOUBLE(asdecimal=False)) #持仓市值
+    rank3_stockweight = Column(DOUBLE(asdecimal=False)) #持仓权重
+    rank3_type = Column(CHAR(20)) #类型
+    rank4_stock = Column(TEXT) #股票名
+    rank4_stock_code = Column(TEXT)  # 股票ID
+    rank4_stockval = Column(DOUBLE(asdecimal=False)) #持仓市值
+    rank4_stockweight = Column(DOUBLE(asdecimal=False)) #持仓权重
+    rank4_type = Column(CHAR(20)) #类型
+    rank5_stock = Column(TEXT) #股票名
+    rank5_stock_code = Column(TEXT)  # 股票ID
+    rank5_stockval = Column(DOUBLE(asdecimal=False)) #持仓市值
+    rank5_stockweight = Column(DOUBLE(asdecimal=False)) #持仓权重
+    rank5_type = Column(CHAR(20)) #类型
+    rank6_stock = Column(TEXT) #股票名
+    rank6_stock_code = Column(TEXT)  # 股票ID
+    rank6_stockval = Column(DOUBLE(asdecimal=False)) #持仓市值
+    rank6_stockweight = Column(DOUBLE(asdecimal=False)) #持仓权重
+    rank6_type = Column(CHAR(20)) #类型
+    rank7_stock = Column(TEXT) #股票名
+    rank7_stock_code = Column(TEXT)  # 股票ID
+    rank7_stockval = Column(DOUBLE(asdecimal=False)) #持仓市值
+    rank7_stockweight = Column(DOUBLE(asdecimal=False)) #持仓权重
+    rank7_type = Column(CHAR(20)) #类型
+    rank8_stock = Column(TEXT) #股票名
+    rank8_stock_code = Column(TEXT)  # 股票ID
+    rank8_stockval = Column(DOUBLE(asdecimal=False)) #持仓市值
+    rank8_stockweight = Column(DOUBLE(asdecimal=False)) #持仓权重
+    rank8_type = Column(CHAR(20)) #类型
+    rank9_stock = Column(TEXT) #股票名
+    rank9_stock_code = Column(TEXT)  # 股票ID
+    rank9_stockval = Column(DOUBLE(asdecimal=False)) #持仓市值
+    rank9_stockweight = Column(DOUBLE(asdecimal=False)) #持仓权重
+    rank9_type = Column(CHAR(20)) #类型
+    rank10_stock = Column(TEXT) #股票名
+    rank10_stock_code = Column(TEXT)  # 股票ID
+    rank10_stockval = Column(DOUBLE(asdecimal=False)) #持仓市值
+    rank10_stockweight = Column(DOUBLE(asdecimal=False)) #持仓权重
+    rank10_type = Column(CHAR(20)) #类型
+    rank11_stock = Column(TEXT) #股票名
+    rank11_stock_code = Column(TEXT)  # 股票ID
+    rank11_stockval = Column(DOUBLE(asdecimal=False)) #持仓市值
+    rank11_stockweight = Column(DOUBLE(asdecimal=False)) #持仓权重
+    rank11_type = Column(CHAR(20)) #类型
+    rank12_stock = Column(TEXT) #股票名
+    rank12_stock_code = Column(TEXT)  # 股票ID
+    rank12_stockval = Column(DOUBLE(asdecimal=False)) #持仓市值
+    rank12_stockweight = Column(DOUBLE(asdecimal=False)) #持仓权重
+    rank12_type = Column(CHAR(20)) #类型
+    rank13_stock = Column(TEXT) #股票名
+    rank13_stock_code = Column(TEXT)  # 股票ID
+    rank13_stockval = Column(DOUBLE(asdecimal=False)) #持仓市值
+    rank13_stockweight = Column(DOUBLE(asdecimal=False)) #持仓权重
+    rank13_type = Column(CHAR(20)) #类型
+    rank14_stock = Column(TEXT) #股票名
+    rank14_stock_code = Column(TEXT)  # 股票ID
+    rank14_stockval = Column(DOUBLE(asdecimal=False)) #持仓市值
+    rank14_stockweight = Column(DOUBLE(asdecimal=False)) #持仓权重
+    rank14_type = Column(CHAR(20)) #类型
+    rank15_stock = Column(TEXT) #股票名
+    rank15_stock_code = Column(TEXT)  # 股票ID
+    rank15_stockval = Column(DOUBLE(asdecimal=False)) #持仓市值
+    rank15_stockweight = Column(DOUBLE(asdecimal=False)) #持仓权重
+    rank15_type = Column(CHAR(20)) #类型
+    rank16_stock = Column(TEXT) #股票名
+    rank16_stock_code = Column(TEXT)  # 股票ID
+    rank16_stockval = Column(DOUBLE(asdecimal=False)) #持仓市值
+    rank16_stockweight = Column(DOUBLE(asdecimal=False)) #持仓权重
+    rank16_type = Column(CHAR(20)) #类型
+    rank17_stock = Column(TEXT) #股票名
+    rank17_stock_code = Column(TEXT)  # 股票ID
+    rank17_stockval = Column(DOUBLE(asdecimal=False)) #持仓市值
+    rank17_stockweight = Column(DOUBLE(asdecimal=False)) #持仓权重
+    rank17_type = Column(CHAR(20)) #类型
+    rank18_stock = Column(TEXT) #股票名
+    rank18_stock_code = Column(TEXT)  # 股票ID
+    rank18_stockval = Column(DOUBLE(asdecimal=False)) #持仓市值
+    rank18_stockweight = Column(DOUBLE(asdecimal=False)) #持仓权重
+    rank18_type = Column(CHAR(20)) #类型
+    rank19_stock = Column(TEXT) #股票名
+    rank19_stock_code = Column(TEXT)  # 股票ID
+    rank19_stockval = Column(DOUBLE(asdecimal=False)) #持仓市值
+    rank19_stockweight = Column(DOUBLE(asdecimal=False)) #持仓权重
+    rank19_type = Column(CHAR(20)) #类型
+    rank20_stock = Column(TEXT) #股票名
+    rank20_stock_code = Column(TEXT)  # 股票ID
+    rank20_stockval = Column(DOUBLE(asdecimal=False)) #持仓市值
+    rank20_stockweight = Column(DOUBLE(asdecimal=False)) #持仓权重
+    rank20_type = Column(CHAR(20)) #类型
+
 class EMFundHoldBond(Base):
     '''东财基金重仓债'''
 
@@ -1279,11 +1415,12 @@ class EmBondInfo(Base):
 
     CODES = Column('bond_id', CHAR(16), primary_key=True) # EM债券ID
     NAME = Column("name", TEXT, nullable=False) # 债券名称
-    CORPCODE = Column('corp_code', CHAR(32)) # 公司债对应上市公司代码
+    CORPCODE = Column('corp_code', CHAR(64)) # 公司债对应上市公司代码
     EM1TYPE = Column('em1_type', CHAR(12)) # 东财债券一级分类
     EM2TYPE = Column('em2_type', CHAR(12)) # 东财债券二级分类
     CBL1TYPE = Column('cbl1_type', CHAR(16)) # 中债债券一级分类
     CBL2TYPE = Column('cbl2_type', CHAR(16)) # 中债债券二级分类
+    ISCITYBOND = Column('is_city_bond', TINYINT(1)) # 是否城投债
 
 class EmBondRating(Base):
     '''Choice债券评级'''
